diff --git a/force_bdss/notification_listeners/base_notification_listener_model.py b/force_bdss/notification_listeners/base_notification_listener_model.py
index 821a650f0cd404b4e207f3a465d77c4c0d108b2a..ef7e58b044cc31e1be9bacd3772c8b2658cf901a 100644
--- a/force_bdss/notification_listeners/base_notification_listener_model.py
+++ b/force_bdss/notification_listeners/base_notification_listener_model.py
@@ -5,7 +5,7 @@ from force_bdss.notification_listeners.i_notification_listener_factory import \
 
 
 class BaseNotificationListenerModel(ABCHasStrictTraits):
-    """Base class for the specific MCO models.
+    """Base class for the specific Notification Listener models.
     This model will also provide, through traits/traitsui magic the View
     that will appear in the workflow manager UI.
diff --git a/force_bdss/notification_listeners/base_notification_listener.py b/force_bdss/notification_listeners/base_notification_listener.py
index 3ea02afd4bcb8001a5e4441d30e105d9f4155033..e4f94647250c7b82b08e638fdf2295cf191135d0 100644
--- a/force_bdss/notification_listeners/base_notification_listener.py
+++ b/force_bdss/notification_listeners/base_notification_listener.py
@@ -8,18 +8,18 @@ from .i_notification_listener_factory import INotificationListenerFactory
 class BaseNotificationListener(ABCHasStrictTraits):
     """Base class for the Notification Listener.
 
     Inherit this class for your MCO implementation
     """
     #: A reference to the factory
     factory = Instance(INotificationListenerFactory)
 
     def __init__(self, factory, *args, **kwargs):
-        """Initializes the MCO.
+        """Initializes the notification listener.
 
         Parameters
         ----------
-        factory: BaseMCOFactory
-            The factory this BaseMCO belongs to
+        factory: BaseNotificationListener
+            The factory this Notification Listener belongs to
         """
         self.factory = factory
         super(BaseNotificationListener, self).__init__(*args, **kwargs)
@@ -8,18 +8,18 @@ from .i_notification_listener_factory import INotificationListenerFactory
     """Base class for the Notification Listener.
 
-    Inherit this class for your MCO implementation
+    Inherit this class for your listener implementation
     """
     #: A reference to the factory